@@ -17,6 +17,9 @@ import sys
 import time
 from gettext import gettext as _
 
+import gi
+gi.require_version('Gdk', '3.0')
+gi.require_version('Gtk', '3.0')
 from gi.repository import GObject, Gdk, Gtk #, Pango
 
 import apt
